/*
 * Copyright 2025 Squircle CE contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.blacksquircle.ui.ds.layout

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.BoxScope
import androidx.compose.foundation.layout.Row
import androidx.compose.material.Icon
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.PreviewLightDark
import com.blacksquircle.ui.ds.PreviewBackground
import com.blacksquircle.ui.ds.R
import com.blacksquircle.ui.ds.SquircleTheme

@Composable
fun ThreeSlotLayout(
    modifier: Modifier = Modifier,
    middleContent: @Composable (BoxScope.() -> Unit)? = null,
    startContent: @Composable (BoxScope.() -> Unit)? = null,
    endContent: @Composable (BoxScope.() -> Unit)? = null,
) {
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
    ) {
        if (startContent != null) {
            Box(
                contentAlignment = Alignment.Center,
                content = startContent,
            )
        }
        if (middleContent != null) {
            Box(
                contentAlignment = Alignment.Center,
                content = middleContent,
                modifier = Modifier.weight(1f, fill = false)
            )
        }
        if (endContent != null) {
            Box(
                contentAlignment = Alignment.Center,
                content = endContent,
            )
        }
    }
}

@PreviewLightDark
@Composable
private fun ThreeSlotLayoutPreview() {
    PreviewBackground {
        ThreeSlotLayout(
            startContent = {
                Icon(
                    painter = painterResource(R.drawable.ic_search),
                    contentDescription = null,
                )
            },
            middleContent = {
                Text(
                    text = "Example",
                    color = SquircleTheme.colors.colorTextAndIconPrimary,
                    style = SquircleTheme.typography.text16Regular,
                )
            },
            endContent = {
                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = null,
                )
            }
        )
    }
}