/*
 * Copyright 2025 Squircle CE contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.blacksquircle.ui.feature.explorer.ui.explorer

import androidx.compose.runtime.Immutable
import com.blacksquircle.ui.core.mvi.ViewState
import com.blacksquircle.ui.feature.explorer.domain.model.FilesystemModel
import com.blacksquircle.ui.feature.explorer.domain.model.SortMode
import com.blacksquircle.ui.feature.explorer.domain.model.TaskType
import com.blacksquircle.ui.feature.explorer.domain.model.ViewMode
import com.blacksquircle.ui.feature.explorer.ui.explorer.model.BreadcrumbState
import com.blacksquircle.ui.filesystem.base.model.FileModel

@Immutable
internal data class ExplorerViewState(
    val filesystems: List<FilesystemModel> = emptyList(),
    val selectedFilesystem: String = "",
    val breadcrumbs: List<BreadcrumbState> = emptyList(),
    val selectedBreadcrumb: Int = -1,
    val selectedFiles: List<FileModel> = emptyList(),
    val searchQuery: String = "",
    val showHidden: Boolean = true,
    val sortMode: SortMode = SortMode.SORT_BY_NAME,
    val viewMode: ViewMode = ViewMode.COMPACT_LIST,
    val taskType: TaskType = TaskType.CREATE,
    val isLoading: Boolean = true,
) : ViewState